"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const winston = require("winston");
const markdown_document_1 = require("../markdown-document");
class Cli {
    generate(yargs) {
        winston.configure({
            level: yargs.logLevel,
            transports: [
                new winston.transports.Console({
                    colorize: true
                })
            ]
        });
        let options = {
            documentPath: path.resolve(yargs.in),
            outputPath: yargs.out == null ? null : path.join(process.cwd(), yargs.out),
            layout: yargs.layout
        };
        if (yargs.temp) {
            options.tempPath = path.join(process.cwd(), yargs.temp);
        }
        const document = new markdown_document_1.MarkdownDocument(options);
        document.createPdfAsync()
            .then(() => {
            winston.info('Finished PDF generation');
        })
            .catch(error => {
            winston.warn('Failed to generate PDF');
            winston.error(error);
        });
    }
}
exports.Cli = Cli;
