"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const winston = require("winston");
const options_service_1 = require("./services/options-service");
const markdown_service_1 = require("./services/markdown-service");
const layout_service_1 = require("./services/layout-service");
const file_service_1 = require("./services/file-service");
const pdf_service_1 = require("./services/pdf-service");
const metadata_service_1 = require("./services/metadata-service");
class MarkdownDocument {
    constructor(options) {
        this.options = options;
    }
    createPdfAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            let timer = winston.startTimer();
            yield options_service_1.default.consolidateAsync(this.options);
            timer.done('Loading options finished');
            timer = winston.startTimer();
            yield this.checkPreconditionsAsync();
            timer.done('Checked preconditions');
            timer = winston.startTimer();
            const markdownAsHtml = yield markdown_service_1.default.renderFileAsync(this.options.documentPath);
            const markdownMeta = markdown_service_1.default.getMetadata();
            timer.done('Render markdown to html finished');
            timer = winston.startTimer();
            const tempPath = yield layout_service_1.default.applyLayoutAsync(this.options.layout, markdownAsHtml, this.options, { meta: markdownMeta });
            timer.done('Applying layout finished');
            timer = winston.startTimer();
            yield pdf_service_1.default.renderPdfAsync(tempPath.path, this.options.outputPath, this.options.pdf);
            timer.done('Rendering pdf finished');
            if (this.options.writeMetadata && this.options.document != null) {
                timer = winston.startTimer();
                yield metadata_service_1.default.setMetadataAsync(this.options.outputPath, {
                    Title: this.options.document.title,
                    Subject: this.options.document.subject,
                    Author: this.options.document.authors.join(';'),
                    Keywords: this.options.document.keywords || []
                });
                timer.done('Setting pdf metadata finished');
            }
            yield tempPath.deleteAsync();
        });
    }
    checkPreconditionsAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            if (yield file_service_1.default.existsAsync(this.options.outputPath)) {
                try {
                    yield file_service_1.default.deleteFileAsync(this.options.outputPath);
                }
                catch (_a) {
                    throw new Error(`The output file '${this.options.outputPath}' is not writable!`);
                }
            }
        });
    }
}
exports.MarkdownDocument = MarkdownDocument;
