"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const os = require("os");
const fs = require("fs");
const path = require("path");
const tmp = require("tmp");
const q = require("q");
const process = require("process");
const temp_path_1 = require("../helpers/temp-path");
class FileService {
    exists(path) {
        return fs.existsSync(path);
    }
    existsAsync(path) {
        return this.nfCallNoError(fs.exists, path);
    }
    readFile(path) {
        return fs.readFileSync(path);
    }
    readFileAsync(path) {
        return q.nfcall(fs.readFile, path);
    }
    writeFileAsync(path, content) {
        return q.nfcall(fs.writeFile, path, content);
    }
    readDirectoryAsync(directory) {
        return q.nfcall(fs.readdir, directory);
    }
    isDirectoryAsync(directory) {
        return __awaiter(this, void 0, void 0, function* () {
            const stat = yield q.nfcall(fs.lstat, directory);
            return stat.isDirectory();
        });
    }
    deleteDirectoryRecursiveAsync(directory) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!(yield this.existsAsync(directory))) {
                return;
            }
            const content = yield this.readDirectoryAsync(directory);
            for (let fileOrFolder of content) {
                const fullPath = path.join(directory, fileOrFolder);
                if (yield this.isDirectoryAsync(fullPath)) {
                    yield this.deleteDirectoryRecursiveAsync(fullPath);
                }
                else {
                    yield this.deleteFileAsync(fullPath);
                }
            }
            yield this.deleteDirectoryAsync(directory);
        });
    }
    deleteDirectoryAsync(directory) {
        return __awaiter(this, void 0, void 0, function* () {
            return q.nfcall(fs.rmdir, directory);
        });
    }
    deleteFileAsync(file) {
        return __awaiter(this, void 0, void 0, function* () {
            return q.nfcall(fs.unlink, file);
        });
    }
    createDirectoryRecursiveAsync(directory) {
        return __awaiter(this, void 0, void 0, function* () {
            const normalizedDirectory = directory.replace(/[\\\/]/g, path.sep);
            let parentDir = path.isAbsolute(normalizedDirectory) ? path.sep : '';
            const dirs = normalizedDirectory.split(path.sep);
            for (let childDir of dirs) {
                parentDir = path.resolve(parentDir, childDir);
                if (!(yield this.existsAsync(parentDir))) {
                    yield this.createDirectoryAsync(parentDir);
                }
            }
        });
    }
    createDirectoryAsync(directory) {
        return __awaiter(this, void 0, void 0, function* () {
            return q.nfcall(fs.mkdir, directory);
        });
    }
    createTempFileAsync(options) {
        const defer = q.defer();
        tmp.file(options, (err, path, fd, cleanupCallback) => {
            if (err) {
                defer.reject(err);
            }
            else {
                defer.resolve(new temp_path_1.TempPath(path, () => this.deleteFileAsync(path)));
            }
        });
        return defer.promise;
    }
    createTempDirectoryAsync() {
        const defer = q.defer();
        tmp.dir((err, path, cleanupCallback) => {
            if (err) {
                defer.reject(err);
            }
            else {
                defer.resolve(new temp_path_1.TempPath(path, () => this.deleteDirectoryRecursiveAsync(path)));
            }
        });
        return defer.promise;
    }
    changeExt(file, ext = '') {
        return file.replace(/\.[^/.]+$/, '') + ext;
    }
    toAbsoluteFileUrl(url) {
        const absoluteUrl = path.resolve(url).replace(/\\/g, '/');
        const protocol = os.platform() === 'win32' ? 'file:///' : 'file://';
        return protocol + absoluteUrl;
    }
    resolveModuleDirectory(module) {
        const directories = process.mainModule.paths;
        for (let directory of directories) {
            const fullPath = path.join(directory, module);
            if (this.exists(fullPath)) {
                return fullPath;
            }
        }
        throw new Error(`Could not find module '${module}'!`);
    }
    nfCallNoError(nodeFunction, ...args) {
        const defer = q.defer();
        try {
            nodeFunction(...args, function (result) {
                defer.resolve(result);
            });
        }
        catch (ex) {
            defer.reject(ex);
        }
        return defer.promise;
    }
}
exports.FileService = FileService;
exports.default = new FileService();
var temp_path_2 = require("../helpers/temp-path");
exports.TempPath = temp_path_2.TempPath;
