"use strict";
/// <reference path="../definitions/remarkable.d.ts" />
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const Remarkable = require('remarkable');
const hljs = require('highlight.js');
const caption_plugin_1 = require("./markdown/caption-plugin");
const include_plugin_1 = require("./markdown/include-plugin");
const local_to_absolute_image_src_plugin_1 = require("./markdown/local-to-absolute-image-src-plugin");
const RemarkableKatex = require('remarkable-katex');
const file_service_1 = require("./file-service");
class MarkdownService {
    constructor() {
        this.md = this.createRemarkableInstance();
    }
    renderFileAsync(path) {
        return __awaiter(this, void 0, void 0, function* () {
            const file = yield file_service_1.default.readFileAsync(path);
            const renderedMarkdown = this.md.render(file.toString(), { path: path });
            return renderedMarkdown;
        });
    }
    getMetadata() {
        return this.md.meta;
    }
    createRemarkableInstance() {
        const md = new Remarkable({
            xhtmlOut: true,
            highlight: this.highlight
        });
        md.use(caption_plugin_1.CaptionPlugin.register);
        md.use(include_plugin_1.IncludePlugin.register);
        md.use(local_to_absolute_image_src_plugin_1.LocalToAbsoluteImageSrcPlugin.register);
        md.use(RemarkableKatex);
        return md;
    }
    highlight(str, lang) {
        if (lang && hljs.getLanguage(lang)) {
            try {
                return hljs.highlight(lang, str).value;
            }
            catch (err) { }
        }
        try {
            return hljs.highlightAuto(str).value;
        }
        catch (err) { }
        return ''; // use external default escaping
    }
}
exports.MarkdownService = MarkdownService;
exports.default = new MarkdownService();
