"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class CaptionPlugin {
    constructor(md) {
        this.md = md;
        this.md.meta = this.md.meta || {};
        this.md.meta.captions = this.md.meta.captions || {};
    }
    parseBlock(state, startLine, endLine, silent) {
        const beginPos = state.bMarks[startLine];
        const endPos = state.eMarks[startLine];
        const content = state.src.substring(beginPos, endPos);
        const match = CaptionPlugin.REGEX.exec(content);
        if (!match) {
            return false;
        }
        // don't insert any tokens in silent mode
        if (silent) {
            return true;
        }
        state.line = startLine + 1;
        state.tokens.push({
            type: CaptionPlugin.IDENTIFIER,
            lines: [startLine],
            level: state.level,
            meta: {
                match: match
            }
        });
        return true;
    }
    parseInline(state, silent) {
        const content = state.src.slice(state.pos).split('\n')[0];
        const match = CaptionPlugin.REGEX.exec(content);
        if (!match) {
            return false;
        }
        state.pos += match[0].length;
        // don't insert any tokens in silent mode
        if (silent) {
            return true;
        }
        state.tokens.push({
            type: CaptionPlugin.IDENTIFIER,
            meta: {
                match: match
            }
        });
        return true;
    }
    render(tokens, idx, options, env, renderer) {
        const token = tokens[idx];
        const match = token.meta.match;
        const type = match[1];
        const title = match[2];
        const meta = this.getCaptionMetadata(type, title);
        return [
            `<a name="${meta.link}"></a>`,
            `<div class="caption caption-${type.toLowerCase()}">${title}</div>`
        ].join('');
    }
    static register(md) {
        const plugin = new CaptionPlugin(md);
        md.block.ruler.before('code', CaptionPlugin.IDENTIFIER, plugin.parseBlock.bind(plugin));
        md.inline.ruler.push(CaptionPlugin.IDENTIFIER, plugin.parseInline.bind(plugin));
        md.renderer.rules[CaptionPlugin.IDENTIFIER] = plugin.render.bind(plugin);
        return plugin;
    }
    getCaptionMetadata(type, title) {
        const loweredType = type.toLowerCase();
        this.md.meta.captions[loweredType] = this.md.meta.captions[loweredType] || [];
        const captions = this.md.meta.captions[loweredType];
        const caption = {
            index: captions.length + 1,
            link: `${loweredType}-${captions.length + 1}`,
            title: title
        };
        captions.push(caption);
        return caption;
    }
}
CaptionPlugin.IDENTIFIER = 'caption';
CaptionPlugin.REGEX = /^\s*@\(caption \s*([\w\/]+)\s*:\s*(.+?)\s*\)\s*$/;
exports.CaptionPlugin = CaptionPlugin;
