"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const file_service_1 = require("../file-service");
class LocalToAbsoluteImageSrcPlugin {
    constructor(md, originalRenderer) {
        this.md = md;
        this.originalRenderer = originalRenderer;
    }
    render(tokens, idx, options, env, renderer) {
        const token = tokens[idx];
        if (this.shouldTranslate(token.src)) {
            const documentFolder = path.dirname(this.currentFile(env));
            const fullImageSource = path.join(documentFolder, token.src);
            const src = file_service_1.default.toAbsoluteFileUrl(fullImageSource);
            token.src = src;
        }
        return this.originalRenderer.apply(null, arguments);
    }
    shouldTranslate(src) {
        if (src == null) {
            return false;
        }
        if (src.startsWith('http')) {
            return false;
        }
        return true;
    }
    currentFile(env) {
        if (!env.path) {
            throw new Error('No environment variable "path" provided.');
        }
        return env.path;
    }
    static register(md) {
        const plugin = new LocalToAbsoluteImageSrcPlugin(md, md.renderer.rules['image']);
        md.renderer.rules['image'] = plugin.render.bind(plugin);
        return plugin;
    }
}
exports.LocalToAbsoluteImageSrcPlugin = LocalToAbsoluteImageSrcPlugin;
