"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const handlebars_1 = require("handlebars");
const concat_helper_1 = require("./template/concat-helper");
const is_empty_helper_1 = require("./template/is-empty-helper");
const lookup_helper_1 = require("./template/lookup-helper");
const resolve_helper_1 = require("./template/resolve-helper");
const translate_helper_1 = require("./template/translate-helper");
const translation_service_1 = require("./translation-service");
class TemplateService {
    constructor(options) {
        this.options = options;
        this.isInitialized = false;
    }
    applyTemplateAsync(template, data) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.initAsync();
            const compiledTemplate = this.handlebars.compile(template.toString());
            return compiledTemplate(data);
        });
    }
    initAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.isInitialized) {
                return;
            }
            const translationService = new translation_service_1.TranslationService(this.options.layout, this.options.language);
            yield translationService.initAsync();
            this.handlebars = handlebars_1.create();
            const concatHelper = new concat_helper_1.ConcatHelper();
            const isEmptyHelper = new is_empty_helper_1.IsEmptyHelper();
            const lookupHelper = new lookup_helper_1.LookupHelper();
            const resolveHelper = new resolve_helper_1.ResolveHelper();
            const translateHelper = new translate_helper_1.TranslateHelper(translationService);
            this.registerHelper(concatHelper);
            this.registerHelper(isEmptyHelper);
            this.registerHelper(lookupHelper);
            this.registerHelper(resolveHelper);
            this.registerHelper(translateHelper);
        });
    }
    registerHelper(helper) {
        this.handlebars.registerHelper(helper.name, helper.onExecute.bind(helper));
    }
}
exports.TemplateService = TemplateService;
